==> bikeshare_model-0.0.8-py3-none-any.whl: bikeshare_model/processing/data_manager.py <==
import sys
sys.path.append('/Users/ajaysingh/aimlops/Project')

import typing as t
from pathlib import Path
import re

import joblib
import pandas as pd
from sklearn.pipeline import Pipeline

from bikeshare_model import __version__ as _version
from bikeshare_model.config.core import DATASET_DIR, TRAINED_MODEL_DIR, config


##  Pre-Pipeline Preparation

def get_year_and_month(dataframe):

    df = dataframe.copy()
    print("get_year_and_month:"+dataframe)
    # convert 'dteday' column to Datetime datatype
    df['dteday'] = pd.to_datetime(df['dteday'], format='%Y-%m-%d')
    
    #df['dteday'] = pd.to_datetime(df['dteday'], format='%d-%m-%Y')
    df['dteday']=df['dteday']
    # Add new features 'yr' and 'mnth
    df['yr'] = df['dteday'].dt.year.astype(str)
    df['mnth'] = df['dteday'].dt.month_name().astype(str)
    #print("Year and Month")
    return df
 
# 2. processing cabin

#f1=lambda x: 0 if type(x) == float else 1  ## Ternary Expression
  

def pre_pipeline_preparation(*, data_frame: pd.DataFrame) -> pd.DataFrame:
    print("pre_pipeline_preparation:" + data_frame)
    data_frame = get_year_and_month(data_frame)
    #print("yr and month column")
    # drop unnecessary variables
    data_frame.drop(labels=config.model_config.unused_fields, axis=1, inplace=True)
    #print(data_frame.head)
    return data_frame


def _load_raw_dataset(*, file_name: str) -> pd.DataFrame:
    dataframe = pd.read_csv(Path(f"{DATASET_DIR}/{file_name}"))
    return dataframe

def load_dataset(*, file_name: str) -> pd.DataFrame:
    dataframe = pd.read_csv(Path(f"{DATASET_DIR}/{file_name}"))
    transformed = pre_pipeline_preparation(data_frame=dataframe)

    return transformed


def save_pipeline(*, pipeline_to_persist: Pipeline) -> None:
    """Persist the pipeline.
    Saves the versioned model, and overwrites any previous
    saved models. This ensures that when the package is
    published, there is only one trained model that can be
    called, and we know exactly how it was built.
    """

    # Prepare versioned save file name
    save_file_name = f"{config.app_config.pipeline_save_file}{_version}.pkl"
    save_path = TRAINED_MODEL_DIR / save_file_name

    remove_old_pipelines(files_to_keep=[save_file_name])
    joblib.dump(pipeline_to_persist, save_path)


def load_pipeline(*, file_name: str) -> Pipeline:
    """Load a persisted pipeline."""

    file_path = TRAINED_MODEL_DIR / file_name
    trained_model = joblib.load(filename=file_path)
    return trained_model


def remove_old_pipelines(*, files_to_keep: t.List[str]) -> None:
    """
    Remove old model pipelines.
    This is to ensure there is a simple one-to-one
    mapping between the package version and the model
    version to be imported and used by other applications.
    """
    do_not_delete = files_to_keep + ["__init__.py"]
    for model_file in TRAINED_MODEL_DIR.iterdir():
        if model_file.name not in do_not_delete:
            model_file.unlink()

==> bikeshare_model-0.0.9-py3-none-any.whl: bikeshare_model/processing/data_manager.py <==
import sys
sys.path.append('/Users/ajaysingh/aimlops/Project')

import typing as t
from pathlib import Path
import re

import joblib
import pandas as pd
from sklearn.pipeline import Pipeline

from bikeshare_model import __version__ as _version
from bikeshare_model.config.core import DATASET_DIR, TRAINED_MODEL_DIR, config


##  Pre-Pipeline Preparation

def get_year_and_month(dataframe):

    df = dataframe.copy()
    print("get_year_and_month:",dataframe)
    # convert 'dteday' column to Datetime datatype
    df['dteday'] = pd.to_datetime(df['dteday'], format='%Y-%m-%d')
    
    #df['dteday'] = pd.to_datetime(df['dteday'], format='%d-%m-%Y')
    df['dteday']=df['dteday']
    # Add new features 'yr' and 'mnth
    df['yr'] = df['dteday'].dt.year.astype(str)
    df['mnth'] = df['dteday'].dt.month_name().astype(str)
    #print("Year and Month")
    return df
 
# 2. processing cabin

#f1=lambda x: 0 if type(x) == float else 1  ## Ternary Expression
  

def pre_pipeline_preparation(*, data_frame: pd.DataFrame) -> pd.DataFrame:
    print("pre_pipeline_preparation:", data_frame)
    data_frame = get_year_and_month(data_frame)
    #print("yr and month column")
    # drop unnecessary variables
    data_frame.drop(labels=config.model_config.unused_fields, axis=1, inplace=True)
    #print(data_frame.head)
    return data_frame


def _load_raw_dataset(*, file_name: str) -> pd.DataFrame:
    dataframe = pd.read_csv(Path(f"{DATASET_DIR}/{file_name}"))
    return dataframe

def load_dataset(*, file_name: str) -> pd.DataFrame:
    dataframe = pd.read_csv(Path(f"{DATASET_DIR}/{file_name}"))
    transformed = pre_pipeline_preparation(data_frame=dataframe)

    return transformed


def save_pipeline(*, pipeline_to_persist: Pipeline) -> None:
    """Persist the pipeline.
    Saves the versioned model, and overwrites any previous
    saved models. This ensures that when the package is
    published, there is only one trained model that can be
    called, and we know exactly how it was built.
    """

    # Prepare versioned save file name
    save_file_name = f"{config.app_config.pipeline_save_file}{_version}.pkl"
    save_path = TRAINED_MODEL_DIR / save_file_name

    remove_old_pipelines(files_to_keep=[save_file_name])
    joblib.dump(pipeline_to_persist, save_path)


def load_pipeline(*, file_name: str) -> Pipeline:
    """Load a persisted pipeline."""

    file_path = TRAINED_MODEL_DIR / file_name
    trained_model = joblib.load(filename=file_path)
    return trained_model


def remove_old_pipelines(*, files_to_keep: t.List[str]) -> None:
    """
    Remove old model pipelines.
    This is to ensure there is a simple one-to-one
    mapping between the package version and the model
    version to be imported and used by other applications.
    """
    do_not_delete = files_to_keep + ["__init__.py"]
    for model_file in TRAINED_MODEL_DIR.iterdir():
        if model_file.name not in do_not_delete:
            model_file.unlink()
